<?php
/**
 * @file
 * Test class implementations.
 */

/**
 * Testing plugin.
 */
class RulesFactoryUITestPlugin extends RulesPlugin {
  protected $itemName = 'rules_admin_factory_test';

  /**
   * Argument value.
   */
  public $foo;

  /**
   * Creates a plugin with an argument that only the factory UI knows how to use.
   */
  public function __construct($foo = NULL) {
    parent::__construct();
    $this->foo = $foo;
  }

  /**
   * Executes the configuration.
   */
  public function executeByArgs($args = array()) {
    // Not implemented.
  }

  /**
   * Evaluates the element.
   */
  public function evaluate(RulesState $state) {
    // Not implemented.
  }

  /**
   * Returns dummy array for the plugin UI.
   */
  public function &componentVariables() {
    $variables = array();
    return $variables;
  }
}

/**
 * Second testing plugin.
 */
class RulesFactoryUITestPlugin2 extends RulesFactoryUITestPlugin {
  protected $itemName = 'rules_admin_factory_test2';
}

/**
 * Testing factory UI.
 */
class RulesFactoryUITestFactoryUI extends RulesFactoryUI {
  /**
   * Builds factory form for testing.
   */
  public function factoryForm(&$form, &$form_state, $options = array()) {
    // Add a hidden field for 'foo'.
    $form['foo'] = array(
      '#type' => 'hidden',
      '#value' => 'foo',
    );

    // Track form state.
    $form['init'] = array(
      '#type' => 'item',
      '#markup' => $this->getYesNoMarkup('init', !empty($options['init'])),
    );
    $form['validate'] = array(
      '#type' => 'item',
      '#markup' => $this->getYesNoMarkup('validate', !empty($form_state['form_validate'])),
    );

    // Track component.
    $form['rules_config_foo'] = array(
      '#type' => 'item',
      '#markup' => $this->getMarkup('foo', isset($form_state['rules_config']) ? (string) $form_state['rules_config']->foo : ''),
    );
  }

  /**
   * Constructs the markup for an exposed form state value.
   */
  protected function getMarkup($name, $value) {
    return '[factory form ' . $name . ': ' . $value . ']';
  }

  /**
   * Constructs the form state markup for a boolean value.
   */
  protected function getYesNoMarkup($name, $value) {
    return $this->getMarkup($name, $value ? 'yes' : 'no');
  }

  /**
   * Validates the form.
   */
  public function factoryFormValidate(&$form, &$form_state, $options = array()) {
    $form_state['form_validate'] = TRUE;
  }

  /**
   * Creates an instance of RulesFactoryUITestPlugin.
   */
  public function factoryFormSubmit(&$form, &$form_state, $options = array()) {
    $foo = $form_state['values']['foo'];
    $form_state['rules_config'] = new RulesFactoryUITestPlugin($foo);
  }
}

/**
 * Factory form for second test plugin.
 */
class RulesFactoryUITestFactoryUI2 extends RulesFactoryUITestFactoryUI {
  /**
   * Overrides the default value of 'foo'.
   */
  public function factoryForm(&$form, &$form_state, $options = array()) {
    parent::factoryForm($form, $form_state, $options);

    // Change value of 'foo'.
    $form['foo']['#value'] = 'foo2';

    // Show class of the plugin.
    $form['test2'] = array(
      '#type' => 'item',
      '#markup' => $this->getYesNoMarkup('test2', TRUE),
    );

    // Show class of the plugin.
    $form['rules_config_class'] = array(
      '#type' => 'item',
      '#markup' => $this->getMarkup('class', isset($form_state['rules_config']) ? get_class($form_state['rules_config']) : ''),
    );
  }

  /**
   * Creates an instance of RulesFactoryUITestPlugin2.
   */
  public function factoryFormSubmit(&$form, &$form_state, $options = array()) {
    $foo = $form_state['values']['foo'];
    $form_state['rules_config'] = new RulesFactoryUITestPlugin2($foo);
  }
}
